@@ -17,8 +17,8 @@ import (
 	"k8s.io/client-go/dynamic"
 	"k8s.io/client-go/kubernetes"
 
-	workclientset "github.com/open-cluster-management/api/client/work/clientset/versioned"
-	workapiv1 "github.com/open-cluster-management/api/work/v1"
+	workclientset "open-cluster-management.io/api/client/work/clientset/versioned"
+	workapiv1 "open-cluster-management.io/api/work/v1"
 )
 
 func AssertWorkCondition(namespace, name string, workClient workclientset.Interface, expectedType string, expectedWorkStatus metav1.ConditionStatus,
@@ -39,6 +39,27 @@ func AssertWorkCondition(namespace, name string, workClient workclientset.Interf
 	}, eventuallyTimeout, eventuallyInterval).Should(gomega.BeTrue())
 }
 
+func AssertWorkGeneration(namespace, name string, workClient workclientset.Interface, expectedType string, eventuallyTimeout, eventuallyInterval int) {
+	gomega.Eventually(func() bool {
+		work, err := workClient.WorkV1().ManifestWorks(namespace).Get(context.Background(), name, metav1.GetOptions{})
+		if err != nil {
+			return false
+		}
+
+		// check manifest status conditions
+		condition := meta.FindStatusCondition(work.Status.Conditions, expectedType)
+		if condition == nil {
+			return false
+		}
+
+		if condition.ObservedGeneration != work.Generation {
+			return false
+		}
+
+		return true
+	}, eventuallyTimeout, eventuallyInterval).Should(gomega.BeTrue())
+}
+
 // check if work is deleted
 func AssertWorkDeleted(namespace, name, hubhash string, manifests []workapiv1.Manifest, workClient workclientset.Interface, kubeClient kubernetes.Interface, eventuallyTimeout, eventuallyInterval int) {
 	// wait for deletion of manifest work
@@ -93,21 +114,21 @@ func AssertFinalizerAdded(namespace, name string, workClient workclientset.Inter
 
 // check if all manifests are applied
 func AssertExistenceOfConfigMaps(manifests []workapiv1.Manifest, kubeClient kubernetes.Interface, eventuallyTimeout, eventuallyInterval int) {
-	gomega.Eventually(func() bool {
+	gomega.Eventually(func() error {
 		for _, manifest := range manifests {
 			expected := manifest.Object.(*corev1.ConfigMap)
 			actual, err := kubeClient.CoreV1().ConfigMaps(expected.Namespace).Get(context.Background(), expected.Name, metav1.GetOptions{})
 			if err != nil {
-				return false
+				return err
 			}
 
 			if !reflect.DeepEqual(actual.Data, expected.Data) {
-				return false
+				return fmt.Errorf("configmap should be equal to %v, but got %v", expected.Data, actual.Data)
 			}
 		}
 
-		return true
-	}, eventuallyTimeout, eventuallyInterval).Should(gomega.BeTrue())
+		return nil
+	}, eventuallyTimeout, eventuallyInterval).ShouldNot(gomega.HaveOccurred())
 }
 
 // check the existence of resource with GVR, namespace and name
